@@ -9,15 +9,13 @@ from .embedding import EmbeddingClient
 from .index import IndexClient
 from .models import CollectionMeta, IndexMeta, __all__ as _models_all  # noqa: F401
 from .models import *  # noqa: F401,F403
-from .exceptions import VikingVectorException, VikingVectorException
-
+from .exceptions import VikingVectorException
 __all__ = [
     "VikingVector",
     "CollectionClient",
     "IndexClient",
     "EmbeddingClient",
     "VikingVectorException",
-    "VikingVectorException",
 ] + list(_models_all)
 
 del _models_all
