@@ -3,7 +3,7 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Mapping, Optional, Union, cast
+from typing import Mapping, Optional, Union, cast
 
 from ..request_options import RequestOptions
 from .base import VectorClientBase
